package tracepb
import "cloud.google.com/go/trace/apiv2/tracepb"
Index ¶
- Constants
- Variables
- func RegisterTraceServiceServer(s grpc.ServiceRegistrar, srv TraceServiceServer)
- type AttributeValue
- func (*AttributeValue) Descriptor() ([]byte, []int)
- func (x *AttributeValue) GetBoolValue() bool
- func (x *AttributeValue) GetIntValue() int64
- func (x *AttributeValue) GetStringValue() *TruncatableString
- func (m *AttributeValue) GetValue() isAttributeValue_Value
- func (*AttributeValue) ProtoMessage()
- func (x *AttributeValue) ProtoReflect() protoreflect.Message
- func (x *AttributeValue) Reset()
- func (x *AttributeValue) String() string
- type AttributeValue_BoolValue
- type AttributeValue_IntValue
- type AttributeValue_StringValue
- type BatchWriteSpansRequest
- func (*BatchWriteSpansRequest) Descriptor() ([]byte, []int)
- func (x *BatchWriteSpansRequest) GetName() string
- func (x *BatchWriteSpansRequest) GetSpans() []*Span
- func (*BatchWriteSpansRequest) ProtoMessage()
- func (x *BatchWriteSpansRequest) ProtoReflect() protoreflect.Message
- func (x *BatchWriteSpansRequest) Reset()
- func (x *BatchWriteSpansRequest) String() string
- type Module
- func (*Module) Descriptor() ([]byte, []int)
- func (x *Module) GetBuildId() *TruncatableString
- func (x *Module) GetModule() *TruncatableString
- func (*Module) ProtoMessage()
- func (x *Module) ProtoReflect() protoreflect.Message
- func (x *Module) Reset()
- func (x *Module) String() string
- type Span
- func (*Span) Descriptor() ([]byte, []int)
- func (x *Span) GetAttributes() *Span_Attributes
- func (x *Span) GetChildSpanCount() *wrapperspb.Int32Value
- func (x *Span) GetDisplayName() *TruncatableString
- func (x *Span) GetEndTime() *timestamppb.Timestamp
- func (x *Span) GetLinks() *Span_Links
- func (x *Span) GetName() string
- func (x *Span) GetParentSpanId() string
- func (x *Span) GetSameProcessAsParentSpan() *wrapperspb.BoolValue
- func (x *Span) GetSpanId() string
- func (x *Span) GetSpanKind() Span_SpanKind
- func (x *Span) GetStackTrace() *StackTrace
- func (x *Span) GetStartTime() *timestamppb.Timestamp
- func (x *Span) GetStatus() *status.Status
- func (x *Span) GetTimeEvents() *Span_TimeEvents
- func (*Span) ProtoMessage()
- func (x *Span) ProtoReflect() protoreflect.Message
- func (x *Span) Reset()
- func (x *Span) String() string
- type Span_Attributes
- func (*Span_Attributes) Descriptor() ([]byte, []int)
- func (x *Span_Attributes) GetAttributeMap() map[string]*AttributeValue
- func (x *Span_Attributes) GetDroppedAttributesCount() int32
- func (*Span_Attributes) ProtoMessage()
- func (x *Span_Attributes) ProtoReflect() protoreflect.Message
- func (x *Span_Attributes) Reset()
- func (x *Span_Attributes) String() string
- type Span_Link
- func (*Span_Link) Descriptor() ([]byte, []int)
- func (x *Span_Link) GetAttributes() *Span_Attributes
- func (x *Span_Link) GetSpanId() string
- func (x *Span_Link) GetTraceId() string
- func (x *Span_Link) GetType() Span_Link_Type
- func (*Span_Link) ProtoMessage()
- func (x *Span_Link) ProtoReflect() protoreflect.Message
- func (x *Span_Link) Reset()
- func (x *Span_Link) String() string
- type Span_Link_Type
- func (Span_Link_Type) Descriptor() protoreflect.EnumDescriptor
- func (x Span_Link_Type) Enum() *Span_Link_Type
- func (Span_Link_Type) EnumDescriptor() ([]byte, []int)
- func (x Span_Link_Type) Number() protoreflect.EnumNumber
- func (x Span_Link_Type) String() string
- func (Span_Link_Type) Type() protoreflect.EnumType
- type Span_Links
- func (*Span_Links) Descriptor() ([]byte, []int)
- func (x *Span_Links) GetDroppedLinksCount() int32
- func (x *Span_Links) GetLink() []*Span_Link
- func (*Span_Links) ProtoMessage()
- func (x *Span_Links) ProtoReflect() protoreflect.Message
- func (x *Span_Links) Reset()
- func (x *Span_Links) String() string
- type Span_SpanKind
- func (Span_SpanKind) Descriptor() protoreflect.EnumDescriptor
- func (x Span_SpanKind) Enum() *Span_SpanKind
- func (Span_SpanKind) EnumDescriptor() ([]byte, []int)
- func (x Span_SpanKind) Number() protoreflect.EnumNumber
- func (x Span_SpanKind) String() string
- func (Span_SpanKind) Type() protoreflect.EnumType
- type Span_TimeEvent
- func (*Span_TimeEvent) Descriptor() ([]byte, []int)
- func (x *Span_TimeEvent) GetAnnotation() *Span_TimeEvent_Annotation
- func (x *Span_TimeEvent) GetMessageEvent() *Span_TimeEvent_MessageEvent
- func (x *Span_TimeEvent) GetTime() *timestamppb.Timestamp
- func (m *Span_TimeEvent) GetValue() isSpan_TimeEvent_Value
- func (*Span_TimeEvent) ProtoMessage()
- func (x *Span_TimeEvent) ProtoReflect() protoreflect.Message
- func (x *Span_TimeEvent) Reset()
- func (x *Span_TimeEvent) String() string
- type Span_TimeEvent_Annotation
- func (*Span_TimeEvent_Annotation) Descriptor() ([]byte, []int)
- func (x *Span_TimeEvent_Annotation) GetAttributes() *Span_Attributes
- func (x *Span_TimeEvent_Annotation) GetDescription() *TruncatableString
- func (*Span_TimeEvent_Annotation) ProtoMessage()
- func (x *Span_TimeEvent_Annotation) ProtoReflect() protoreflect.Message
- func (x *Span_TimeEvent_Annotation) Reset()
- func (x *Span_TimeEvent_Annotation) String() string
- type Span_TimeEvent_Annotation_
- type Span_TimeEvent_MessageEvent
- func (*Span_TimeEvent_MessageEvent) Descriptor() ([]byte, []int)
- func (x *Span_TimeEvent_MessageEvent) GetCompressedSizeBytes() int64
- func (x *Span_TimeEvent_MessageEvent) GetId() int64
- func (x *Span_TimeEvent_MessageEvent) GetType() Span_TimeEvent_MessageEvent_Type
- func (x *Span_TimeEvent_MessageEvent) GetUncompressedSizeBytes() int64
- func (*Span_TimeEvent_MessageEvent) ProtoMessage()
- func (x *Span_TimeEvent_MessageEvent) ProtoReflect() protoreflect.Message
- func (x *Span_TimeEvent_MessageEvent) Reset()
- func (x *Span_TimeEvent_MessageEvent) String() string
- type Span_TimeEvent_MessageEvent_
- type Span_TimeEvent_MessageEvent_Type
- func (Span_TimeEvent_MessageEvent_Type) Descriptor() protoreflect.EnumDescriptor
- func (x Span_TimeEvent_MessageEvent_Type) Enum() *Span_TimeEvent_MessageEvent_Type
- func (Span_TimeEvent_MessageEvent_Type) EnumDescriptor() ([]byte, []int)
- func (x Span_TimeEvent_MessageEvent_Type) Number() protoreflect.EnumNumber
- func (x Span_TimeEvent_MessageEvent_Type) String() string
- func (Span_TimeEvent_MessageEvent_Type) Type() protoreflect.EnumType
- type Span_TimeEvents
- func (*Span_TimeEvents) Descriptor() ([]byte, []int)
- func (x *Span_TimeEvents) GetDroppedAnnotationsCount() int32
- func (x *Span_TimeEvents) GetDroppedMessageEventsCount() int32
- func (x *Span_TimeEvents) GetTimeEvent() []*Span_TimeEvent
- func (*Span_TimeEvents) ProtoMessage()
- func (x *Span_TimeEvents) ProtoReflect() protoreflect.Message
- func (x *Span_TimeEvents) Reset()
- func (x *Span_TimeEvents) String() string
- type StackTrace
- func (*StackTrace) Descriptor() ([]byte, []int)
- func (x *StackTrace) GetStackFrames() *StackTrace_StackFrames
- func (x *StackTrace) GetStackTraceHashId() int64
- func (*StackTrace) ProtoMessage()
- func (x *StackTrace) ProtoReflect() protoreflect.Message
- func (x *StackTrace) Reset()
- func (x *StackTrace) String() string
- type StackTrace_StackFrame
- func (*StackTrace_StackFrame) Descriptor() ([]byte, []int)
- func (x *StackTrace_StackFrame) GetColumnNumber() int64
- func (x *StackTrace_StackFrame) GetFileName() *TruncatableString
- func (x *StackTrace_StackFrame) GetFunctionName() *TruncatableString
- func (x *StackTrace_StackFrame) GetLineNumber() int64
- func (x *StackTrace_StackFrame) GetLoadModule() *Module
- func (x *StackTrace_StackFrame) GetOriginalFunctionName() *TruncatableString
- func (x *StackTrace_StackFrame) GetSourceVersion() *TruncatableString
- func (*StackTrace_StackFrame) ProtoMessage()
- func (x *StackTrace_StackFrame) ProtoReflect() protoreflect.Message
- func (x *StackTrace_StackFrame) Reset()
- func (x *StackTrace_StackFrame) String() string
- type StackTrace_StackFrames
- func (*StackTrace_StackFrames) Descriptor() ([]byte, []int)
- func (x *StackTrace_StackFrames) GetDroppedFramesCount() int32
- func (x *StackTrace_StackFrames) GetFrame() []*StackTrace_StackFrame
- func (*StackTrace_StackFrames) ProtoMessage()
- func (x *StackTrace_StackFrames) ProtoReflect() protoreflect.Message
- func (x *StackTrace_StackFrames) Reset()
- func (x *StackTrace_StackFrames) String() string
- type TraceServiceClient
- type TraceServiceServer
- type TruncatableString
- func (*TruncatableString) Descriptor() ([]byte, []int)
- func (x *TruncatableString) GetTruncatedByteCount() int32
- func (x *TruncatableString) GetValue() string
- func (*TruncatableString) ProtoMessage()
- func (x *TruncatableString) ProtoReflect() protoreflect.Message
- func (x *TruncatableString) Reset()
- func (x *TruncatableString) String() string
- type UnimplementedTraceServiceServer
- func (UnimplementedTraceServiceServer) BatchWriteSpans(context.Context, *BatchWriteSpansRequest) (*emptypb.Empty, error)
- func (UnimplementedTraceServiceServer) CreateSpan(context.Context, *Span) (*Span, error)
- type UnsafeTraceServiceServer
Constants ¶
const ( TraceService_BatchWriteSpans_FullMethodName = "/google.devtools.cloudtrace.v2.TraceService/BatchWriteSpans" TraceService_CreateSpan_FullMethodName = "/google.devtools.cloudtrace.v2.TraceService/CreateSpan" )
Variables ¶
var ( Span_SpanKind_name = map[int32]string{ 0: "SPAN_KIND_UNSPECIFIED", 1: "INTERNAL", 2: "SERVER", 3: "CLIENT", 4: "PRODUCER", 5: "CONSUMER", } Span_SpanKind_value = map[string]int32{ "SPAN_KIND_UNSPECIFIED": 0, "INTERNAL": 1, "SERVER": 2, "CLIENT": 3, "PRODUCER": 4, "CONSUMER": 5, } )
Enum value maps for Span_SpanKind.
var ( Span_TimeEvent_MessageEvent_Type_name = map[int32]string{ 0: "TYPE_UNSPECIFIED", 1: "SENT", 2: "RECEIVED", } Span_TimeEvent_MessageEvent_Type_value = map[string]int32{ "TYPE_UNSPECIFIED": 0, "SENT": 1, "RECEIVED": 2, } )
Enum value maps for Span_TimeEvent_MessageEvent_Type.
var ( Span_Link_Type_name = map[int32]string{ 0: "TYPE_UNSPECIFIED", 1: "CHILD_LINKED_SPAN", 2: "PARENT_LINKED_SPAN", } Span_Link_Type_value = map[string]int32{ "TYPE_UNSPECIFIED": 0, "CHILD_LINKED_SPAN": 1, "PARENT_LINKED_SPAN": 2, } )
Enum value maps for Span_Link_Type.
var File_google_devtools_cloudtrace_v2_trace_proto protoreflect.FileDescriptor
var File_google_devtools_cloudtrace_v2_tracing_proto protoreflect.FileDescriptor
var TraceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.devtools.cloudtrace.v2.TraceService", HandlerType: (*TraceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "BatchWriteSpans", Handler: _TraceService_BatchWriteSpans_Handler, }, { MethodName: "CreateSpan", Handler: _TraceService_CreateSpan_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/devtools/cloudtrace/v2/tracing.proto", }
TraceService_ServiceDesc is the grpc.ServiceDesc for TraceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTraceServiceServer ¶
func RegisterTraceServiceServer(s grpc.ServiceRegistrar, srv TraceServiceServer)
Types ¶
type AttributeValue ¶
type AttributeValue struct {
// The type of the value.
//
// Types that are assignable to Value:
//
// *AttributeValue_StringValue
// *AttributeValue_IntValue
// *AttributeValue_BoolValue
Value isAttributeValue_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
The allowed types for `[VALUE]` in a `[KEY]:[VALUE]` attribute.
func (*AttributeValue) Descriptor ¶
func (*AttributeValue) Descriptor() ([]byte, []int)
Deprecated: Use AttributeValue.ProtoReflect.Descriptor instead.
func (*AttributeValue) GetBoolValue ¶
func (x *AttributeValue) GetBoolValue() bool
func (*AttributeValue) GetIntValue ¶
func (x *AttributeValue) GetIntValue() int64
func (*AttributeValue) GetStringValue ¶
func (x *AttributeValue) GetStringValue() *TruncatableString
func (*AttributeValue) GetValue ¶
func (m *AttributeValue) GetValue() isAttributeValue_Value
func (*AttributeValue) ProtoMessage ¶
func (*AttributeValue) ProtoMessage()
func (*AttributeValue) ProtoReflect ¶
func (x *AttributeValue) ProtoReflect() protoreflect.Message
func (*AttributeValue) Reset ¶
func (x *AttributeValue) Reset()
func (*AttributeValue) String ¶
func (x *AttributeValue) String() string
type AttributeValue_BoolValue ¶
type AttributeValue_BoolValue struct {
// A Boolean value represented by `true` or `false`.
BoolValue bool `protobuf:"varint,3,opt,name=bool_value,json=boolValue,proto3,oneof"`
}
type AttributeValue_IntValue ¶
type AttributeValue_IntValue struct {
// A 64-bit signed integer.
IntValue int64 `protobuf:"varint,2,opt,name=int_value,json=intValue,proto3,oneof"`
}
type AttributeValue_StringValue ¶
type AttributeValue_StringValue struct {
// A string up to 256 bytes long.
StringValue *TruncatableString `protobuf:"bytes,1,opt,name=string_value,json=stringValue,proto3,oneof"`
}
type BatchWriteSpansRequest ¶
type BatchWriteSpansRequest struct {
// Required. The name of the project where the spans belong. The format is
// `projects/[PROJECT_ID]`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. A list of new spans. The span names must not match existing
// spans, otherwise the results are undefined.
Spans []*Span `protobuf:"bytes,2,rep,name=spans,proto3" json:"spans,omitempty"`
// contains filtered or unexported fields
}
The request message for the `BatchWriteSpans` method.
func (*BatchWriteSpansRequest) Descriptor ¶
func (*BatchWriteSpansRequest) Descriptor() ([]byte, []int)
Deprecated: Use BatchWriteSpansRequest.ProtoReflect.Descriptor instead.
func (*BatchWriteSpansRequest) GetName ¶
func (x *BatchWriteSpansRequest) GetName() string
func (*BatchWriteSpansRequest) GetSpans ¶
func (x *BatchWriteSpansRequest) GetSpans() []*Span
func (*BatchWriteSpansRequest) ProtoMessage ¶
func (*BatchWriteSpansRequest) ProtoMessage()
func (*BatchWriteSpansRequest) ProtoReflect ¶
func (x *BatchWriteSpansRequest) ProtoReflect() protoreflect.Message
func (*BatchWriteSpansRequest) Reset ¶
func (x *BatchWriteSpansRequest) Reset()
func (*BatchWriteSpansRequest) String ¶
func (x *BatchWriteSpansRequest) String() string
type Module ¶
type Module struct {
// For example: main binary, kernel modules, and dynamic libraries
// such as libc.so, sharedlib.so (up to 256 bytes).
Module *TruncatableString `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
// A unique identifier for the module, usually a hash of its
// contents (up to 128 bytes).
BuildId *TruncatableString `protobuf:"bytes,2,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
// contains filtered or unexported fields
}
Binary module.
func (*Module) Descriptor ¶
Deprecated: Use Module.ProtoReflect.Descriptor instead.
func (*Module) GetBuildId ¶
func (x *Module) GetBuildId() *TruncatableString
func (*Module) GetModule ¶
func (x *Module) GetModule() *TruncatableString
func (*Module) ProtoMessage ¶
func (*Module) ProtoMessage()
func (*Module) ProtoReflect ¶
func (x *Module) ProtoReflect() protoreflect.Message
func (*Module) Reset ¶
func (x *Module) Reset()
func (*Module) String ¶
type Span ¶
type Span struct {
// Required. The resource name of the span in the following format:
//
// - `projects/[PROJECT_ID]/traces/[TRACE_ID]/spans/[SPAN_ID]`
//
// `[TRACE_ID]` is a unique identifier for a trace within a project;
// it is a 32-character hexadecimal encoding of a 16-byte array. It should
// not be zero.
//
// `[SPAN_ID]` is a unique identifier for a span within a trace; it
// is a 16-character hexadecimal encoding of an 8-byte array. It should not
// be zero.
// .
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. The `[SPAN_ID]` portion of the span's resource name.
SpanId string `protobuf:"bytes,2,opt,name=span_id,json=spanId,proto3" json:"span_id,omitempty"`
// The `[SPAN_ID]` of this span's parent span. If this is a root span,
// then this field must be empty.
ParentSpanId string `protobuf:"bytes,3,opt,name=parent_span_id,json=parentSpanId,proto3" json:"parent_span_id,omitempty"`
// Required. A description of the span's operation (up to 128 bytes).
// Cloud Trace displays the description in the
// Cloud console.
// For example, the display name can be a qualified method name or a file name
// and a line number where the operation is called. A best practice is to use
// the same display name within an application and at the same call point.
// This makes it easier to correlate spans in different traces.
DisplayName *TruncatableString `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Required. The start time of the span. On the client side, this is the time
// kept by the local machine where the span execution starts. On the server
// side, this is the time when the server's application handler starts
// running.
StartTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// Required. The end time of the span. On the client side, this is the time
// kept by the local machine where the span execution ends. On the server
// side, this is the time when the server application handler stops running.
EndTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// A set of attributes on the span. You can have up to 32 attributes per
// span.
Attributes *Span_Attributes `protobuf:"bytes,7,opt,name=attributes,proto3" json:"attributes,omitempty"`
// Stack trace captured at the start of the span.
StackTrace *StackTrace `protobuf:"bytes,8,opt,name=stack_trace,json=stackTrace,proto3" json:"stack_trace,omitempty"`
// A set of time events. You can have up to 32 annotations and 128 message
// events per span.
TimeEvents *Span_TimeEvents `protobuf:"bytes,9,opt,name=time_events,json=timeEvents,proto3" json:"time_events,omitempty"`
// Links associated with the span. You can have up to 128 links per Span.
Links *Span_Links `protobuf:"bytes,10,opt,name=links,proto3" json:"links,omitempty"`
// Optional. The final status for this span.
Status *status.Status `protobuf:"bytes,11,opt,name=status,proto3" json:"status,omitempty"`
// Optional. Set this parameter to indicate whether this span is in
// the same process as its parent. If you do not set this parameter,
// Trace is unable to take advantage of this helpful information.
SameProcessAsParentSpan *wrapperspb.BoolValue `protobuf:"bytes,12,opt,name=same_process_as_parent_span,json=sameProcessAsParentSpan,proto3" json:"same_process_as_parent_span,omitempty"`
// Optional. The number of child spans that were generated while this span
// was active. If set, allows implementation to detect missing child spans.
ChildSpanCount *wrapperspb.Int32Value `protobuf:"bytes,13,opt,name=child_span_count,json=childSpanCount,proto3" json:"child_span_count,omitempty"`
// Optional. Distinguishes between spans generated in a particular context.
// For example, two spans with the same name may be distinguished using
// `CLIENT` (caller) and `SERVER` (callee) to identify an RPC call.
SpanKind Span_SpanKind `protobuf:"varint,14,opt,name=span_kind,json=spanKind,proto3,enum=google.devtools.cloudtrace.v2.Span_SpanKind" json:"span_kind,omitempty"`
// contains filtered or unexported fields
}
A span represents a single operation within a trace. Spans can be nested to form a trace tree. Often, a trace contains a root span that describes the end-to-end latency, and one or more subspans for its sub-operations.
A trace can also contain multiple root spans, or none at all. Spans do not need to be contiguous. There might be gaps or overlaps between spans in a trace.
func (*Span) Descriptor ¶
Deprecated: Use Span.ProtoReflect.Descriptor instead.
func (*Span) GetAttributes ¶
func (x *Span) GetAttributes() *Span_Attributes
func (*Span) GetChildSpanCount ¶
func (x *Span) GetChildSpanCount() *wrapperspb.Int32Value
func (*Span) GetDisplayName ¶
func (x *Span) GetDisplayName() *TruncatableString
func (*Span) GetEndTime ¶
func (x *Span) GetEndTime() *timestamppb.Timestamp
func (*Span) GetLinks ¶
func (x *Span) GetLinks() *Span_Links
func (*Span) GetName ¶
func (*Span) GetParentSpanId ¶
func (*Span) GetSameProcessAsParentSpan ¶
func (x *Span) GetSameProcessAsParentSpan() *wrapperspb.BoolValue
func (*Span) GetSpanId ¶
func (*Span) GetSpanKind ¶
func (x *Span) GetSpanKind() Span_SpanKind
func (*Span) GetStackTrace ¶
func (x *Span) GetStackTrace() *StackTrace
func (*Span) GetStartTime ¶
func (x *Span) GetStartTime() *timestamppb.Timestamp
func (*Span) GetStatus ¶
func (*Span) GetTimeEvents ¶
func (x *Span) GetTimeEvents() *Span_TimeEvents
func (*Span) ProtoMessage ¶
func (*Span) ProtoMessage()
func (*Span) ProtoReflect ¶
func (x *Span) ProtoReflect() protoreflect.Message
func (*Span) Reset ¶
func (x *Span) Reset()
func (*Span) String ¶
type Span_Attributes ¶
type Span_Attributes struct {
// A set of attributes. Each attribute's key can be up to 128 bytes
// long. The value can be a string up to 256 bytes, a signed 64-bit integer,
// or the boolean values `true` or `false`. For example:
//
// "/instance_id": { "string_value": { "value": "my-instance" } }
// "/http/request_bytes": { "int_value": 300 }
// "abc.com/myattribute": { "bool_value": false }
AttributeMap map[string]*AttributeValue `protobuf:"bytes,1,rep,name=attribute_map,json=attributeMap,proto3" json:"attribute_map,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// The number of attributes that were discarded. Attributes can be discarded
// because their keys are too long or because there are too many attributes.
// If this value is 0 then all attributes are valid.
DroppedAttributesCount int32 `protobuf:"varint,2,opt,name=dropped_attributes_count,json=droppedAttributesCount,proto3" json:"dropped_attributes_count,omitempty"`
// contains filtered or unexported fields
}
A set of attributes as key-value pairs.
func (*Span_Attributes) Descriptor ¶
func (*Span_Attributes) Descriptor() ([]byte, []int)
Deprecated: Use Span_Attributes.ProtoReflect.Descriptor instead.
func (*Span_Attributes) GetAttributeMap ¶
func (x *Span_Attributes) GetAttributeMap() map[string]*AttributeValue
func (*Span_Attributes) GetDroppedAttributesCount ¶
func (x *Span_Attributes) GetDroppedAttributesCount() int32
func (*Span_Attributes) ProtoMessage ¶
func (*Span_Attributes) ProtoMessage()
func (*Span_Attributes) ProtoReflect ¶
func (x *Span_Attributes) ProtoReflect() protoreflect.Message
func (*Span_Attributes) Reset ¶
func (x *Span_Attributes) Reset()
func (*Span_Attributes) String ¶
func (x *Span_Attributes) String() string
type Span_Link ¶
type Span_Link struct {
// The `[TRACE_ID]` for a trace within a project.
TraceId string `protobuf:"bytes,1,opt,name=trace_id,json=traceId,proto3" json:"trace_id,omitempty"`
// The `[SPAN_ID]` for a span within a trace.
SpanId string `protobuf:"bytes,2,opt,name=span_id,json=spanId,proto3" json:"span_id,omitempty"`
// The relationship of the current span relative to the linked span.
Type Span_Link_Type `protobuf:"varint,3,opt,name=type,proto3,enum=google.devtools.cloudtrace.v2.Span_Link_Type" json:"type,omitempty"`
// A set of attributes on the link. Up to 32 attributes can be
// specified per link.
Attributes *Span_Attributes `protobuf:"bytes,4,opt,name=attributes,proto3" json:"attributes,omitempty"`
// contains filtered or unexported fields
}
A pointer from the current span to another span in the same trace or in a different trace. For example, this can be used in batching operations, where a single batch handler processes multiple requests from different traces or when the handler receives a request from a different project.
func (*Span_Link) Descriptor ¶
Deprecated: Use Span_Link.ProtoReflect.Descriptor instead.
func (*Span_Link) GetAttributes ¶
func (x *Span_Link) GetAttributes() *Span_Attributes
func (*Span_Link) GetSpanId ¶
func (*Span_Link) GetTraceId ¶
func (*Span_Link) GetType ¶
func (x *Span_Link) GetType() Span_Link_Type
func (*Span_Link) ProtoMessage ¶
func (*Span_Link) ProtoMessage()
func (*Span_Link) ProtoReflect ¶
func (x *Span_Link) ProtoReflect() protoreflect.Message
func (*Span_Link) Reset ¶
func (x *Span_Link) Reset()
func (*Span_Link) String ¶
type Span_Link_Type ¶
type Span_Link_Type int32
The relationship of the current span relative to the linked span: child, parent, or unspecified.
const ( // The relationship of the two spans is unknown. Span_Link_TYPE_UNSPECIFIED Span_Link_Type = 0 // The linked span is a child of the current span. Span_Link_CHILD_LINKED_SPAN Span_Link_Type = 1 // The linked span is a parent of the current span. Span_Link_PARENT_LINKED_SPAN Span_Link_Type = 2 )
func (Span_Link_Type) Descriptor ¶
func (Span_Link_Type) Descriptor() protoreflect.EnumDescriptor
func (Span_Link_Type) Enum ¶
func (x Span_Link_Type) Enum() *Span_Link_Type
func (Span_Link_Type) EnumDescriptor ¶
func (Span_Link_Type) EnumDescriptor() ([]byte, []int)
Deprecated: Use Span_Link_Type.Descriptor instead.
func (Span_Link_Type) Number ¶
func (x Span_Link_Type) Number() protoreflect.EnumNumber
func (Span_Link_Type) String ¶
func (x Span_Link_Type) String() string
func (Span_Link_Type) Type ¶
func (Span_Link_Type) Type() protoreflect.EnumType
type Span_Links ¶
type Span_Links struct {
// A collection of links.
Link []*Span_Link `protobuf:"bytes,1,rep,name=link,proto3" json:"link,omitempty"`
// The number of dropped links after the maximum size was enforced. If
// this value is 0, then no links were dropped.
DroppedLinksCount int32 `protobuf:"varint,2,opt,name=dropped_links_count,json=droppedLinksCount,proto3" json:"dropped_links_count,omitempty"`
// contains filtered or unexported fields
}
A collection of links, which are references from this span to a span in the same or different trace.
func (*Span_Links) Descriptor ¶
func (*Span_Links) Descriptor() ([]byte, []int)
Deprecated: Use Span_Links.ProtoReflect.Descriptor instead.
func (*Span_Links) GetDroppedLinksCount ¶
func (x *Span_Links) GetDroppedLinksCount() int32
func (*Span_Links) GetLink ¶
func (x *Span_Links) GetLink() []*Span_Link
func (*Span_Links) ProtoMessage ¶
func (*Span_Links) ProtoMessage()
func (*Span_Links) ProtoReflect ¶
func (x *Span_Links) ProtoReflect() protoreflect.Message
func (*Span_Links) Reset ¶
func (x *Span_Links) Reset()
func (*Span_Links) String ¶
func (x *Span_Links) String() string
type Span_SpanKind ¶
type Span_SpanKind int32
Type of span. Can be used to specify additional relationships between spans in addition to a parent/child relationship.
const ( // Unspecified. Do NOT use as default. // Implementations MAY assume SpanKind.INTERNAL to be default. Span_SPAN_KIND_UNSPECIFIED Span_SpanKind = 0 // Indicates that the span is used internally. Default value. Span_INTERNAL Span_SpanKind = 1 // Indicates that the span covers server-side handling of an RPC or other // remote network request. Span_SERVER Span_SpanKind = 2 // Indicates that the span covers the client-side wrapper around an RPC or // other remote request. Span_CLIENT Span_SpanKind = 3 // Indicates that the span describes producer sending a message to a broker. // Unlike client and server, there is no direct critical path latency // relationship between producer and consumer spans (e.g. publishing a // message to a pubsub service). Span_PRODUCER Span_SpanKind = 4 // Indicates that the span describes consumer receiving a message from a // broker. Unlike client and server, there is no direct critical path // latency relationship between producer and consumer spans (e.g. receiving // a message from a pubsub service subscription). Span_CONSUMER Span_SpanKind = 5 )
func (Span_SpanKind) Descriptor ¶
func (Span_SpanKind) Descriptor() protoreflect.EnumDescriptor
func (Span_SpanKind) Enum ¶
func (x Span_SpanKind) Enum() *Span_SpanKind
func (Span_SpanKind) EnumDescriptor ¶
func (Span_SpanKind) EnumDescriptor() ([]byte, []int)
Deprecated: Use Span_SpanKind.Descriptor instead.
func (Span_SpanKind) Number ¶
func (x Span_SpanKind) Number() protoreflect.EnumNumber
func (Span_SpanKind) String ¶
func (x Span_SpanKind) String() string
func (Span_SpanKind) Type ¶
func (Span_SpanKind) Type() protoreflect.EnumType
type Span_TimeEvent ¶
type Span_TimeEvent struct {
// The timestamp indicating the time the event occurred.
Time *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=time,proto3" json:"time,omitempty"`
// A `TimeEvent` can contain either an `Annotation` object or a
// `MessageEvent` object, but not both.
//
// Types that are assignable to Value:
//
// *Span_TimeEvent_Annotation_
// *Span_TimeEvent_MessageEvent_
Value isSpan_TimeEvent_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
A time-stamped annotation or message event in the Span.
func (*Span_TimeEvent) Descriptor ¶
func (*Span_TimeEvent) Descriptor() ([]byte, []int)
Deprecated: Use Span_TimeEvent.ProtoReflect.Descriptor instead.
func (*Span_TimeEvent) GetAnnotation ¶
func (x *Span_TimeEvent) GetAnnotation() *Span_TimeEvent_Annotation
func (*Span_TimeEvent) GetMessageEvent ¶
func (x *Span_TimeEvent) GetMessageEvent() *Span_TimeEvent_MessageEvent
func (*Span_TimeEvent) GetTime ¶
func (x *Span_TimeEvent) GetTime() *timestamppb.Timestamp
func (*Span_TimeEvent) GetValue ¶
func (m *Span_TimeEvent) GetValue() isSpan_TimeEvent_Value
func (*Span_TimeEvent) ProtoMessage ¶
func (*Span_TimeEvent) ProtoMessage()
func (*Span_TimeEvent) ProtoReflect ¶
func (x *Span_TimeEvent) ProtoReflect() protoreflect.Message
func (*Span_TimeEvent) Reset ¶
func (x *Span_TimeEvent) Reset()
func (*Span_TimeEvent) String ¶
func (x *Span_TimeEvent) String() string
type Span_TimeEvent_Annotation ¶
type Span_TimeEvent_Annotation struct {
// A user-supplied message describing the event. The maximum length for
// the description is 256 bytes.
Description *TruncatableString `protobuf:"bytes,1,opt,name=description,proto3" json:"description,omitempty"`
// A set of attributes on the annotation. You can have up to 4 attributes
// per Annotation.
Attributes *Span_Attributes `protobuf:"bytes,2,opt,name=attributes,proto3" json:"attributes,omitempty"`
// contains filtered or unexported fields
}
Text annotation with a set of attributes.
func (*Span_TimeEvent_Annotation) Descriptor ¶
func (*Span_TimeEvent_Annotation) Descriptor() ([]byte, []int)
Deprecated: Use Span_TimeEvent_Annotation.ProtoReflect.Descriptor instead.
func (*Span_TimeEvent_Annotation) GetAttributes ¶
func (x *Span_TimeEvent_Annotation) GetAttributes() *Span_Attributes
func (*Span_TimeEvent_Annotation) GetDescription ¶
func (x *Span_TimeEvent_Annotation) GetDescription() *TruncatableString
func (*Span_TimeEvent_Annotation) ProtoMessage ¶
func (*Span_TimeEvent_Annotation) ProtoMessage()
func (*Span_TimeEvent_Annotation) ProtoReflect ¶
func (x *Span_TimeEvent_Annotation) ProtoReflect() protoreflect.Message
func (*Span_TimeEvent_Annotation) Reset ¶
func (x *Span_TimeEvent_Annotation) Reset()
func (*Span_TimeEvent_Annotation) String ¶
func (x *Span_TimeEvent_Annotation) String() string
type Span_TimeEvent_Annotation_ ¶
type Span_TimeEvent_Annotation_ struct {
// Text annotation with a set of attributes.
Annotation *Span_TimeEvent_Annotation `protobuf:"bytes,2,opt,name=annotation,proto3,oneof"`
}
type Span_TimeEvent_MessageEvent ¶
type Span_TimeEvent_MessageEvent struct {
// Type of MessageEvent. Indicates whether the message was sent or
// received.
Type Span_TimeEvent_MessageEvent_Type `protobuf:"varint,1,opt,name=type,proto3,enum=google.devtools.cloudtrace.v2.Span_TimeEvent_MessageEvent_Type" json:"type,omitempty"`
// An identifier for the MessageEvent's message that can be used to match
// `SENT` and `RECEIVED` MessageEvents.
Id int64 `protobuf:"varint,2,opt,name=id,proto3" json:"id,omitempty"`
// The number of uncompressed bytes sent or received.
UncompressedSizeBytes int64 `protobuf:"varint,3,opt,name=uncompressed_size_bytes,json=uncompressedSizeBytes,proto3" json:"uncompressed_size_bytes,omitempty"`
// The number of compressed bytes sent or received. If missing, the
// compressed size is assumed to be the same size as the uncompressed
// size.
CompressedSizeBytes int64 `protobuf:"varint,4,opt,name=compressed_size_bytes,json=compressedSizeBytes,proto3" json:"compressed_size_bytes,omitempty"`
// contains filtered or unexported fields
}
An event describing a message sent/received between Spans.
func (*Span_TimeEvent_MessageEvent) Descriptor ¶
func (*Span_TimeEvent_MessageEvent) Descriptor() ([]byte, []int)
Deprecated: Use Span_TimeEvent_MessageEvent.ProtoReflect.Descriptor instead.
func (*Span_TimeEvent_MessageEvent) GetCompressedSizeBytes ¶
func (x *Span_TimeEvent_MessageEvent) GetCompressedSizeBytes() int64
func (*Span_TimeEvent_MessageEvent) GetId ¶
func (x *Span_TimeEvent_MessageEvent) GetId() int64
func (*Span_TimeEvent_MessageEvent) GetType ¶
func (x *Span_TimeEvent_MessageEvent) GetType() Span_TimeEvent_MessageEvent_Type
func (*Span_TimeEvent_MessageEvent) GetUncompressedSizeBytes ¶
func (x *Span_TimeEvent_MessageEvent) GetUncompressedSizeBytes() int64
func (*Span_TimeEvent_MessageEvent) ProtoMessage ¶
func (*Span_TimeEvent_MessageEvent) ProtoMessage()
func (*Span_TimeEvent_MessageEvent) ProtoReflect ¶
func (x *Span_TimeEvent_MessageEvent) ProtoReflect() protoreflect.Message
func (*Span_TimeEvent_MessageEvent) Reset ¶
func (x *Span_TimeEvent_MessageEvent) Reset()
func (*Span_TimeEvent_MessageEvent) String ¶
func (x *Span_TimeEvent_MessageEvent) String() string
type Span_TimeEvent_MessageEvent_ ¶
type Span_TimeEvent_MessageEvent_ struct {
// An event describing a message sent/received between Spans.
MessageEvent *Span_TimeEvent_MessageEvent `protobuf:"bytes,3,opt,name=message_event,json=messageEvent,proto3,oneof"`
}
type Span_TimeEvent_MessageEvent_Type ¶
type Span_TimeEvent_MessageEvent_Type int32
Indicates whether the message was sent or received.
const ( // Unknown event type. Span_TimeEvent_MessageEvent_TYPE_UNSPECIFIED Span_TimeEvent_MessageEvent_Type = 0 // Indicates a sent message. Span_TimeEvent_MessageEvent_SENT Span_TimeEvent_MessageEvent_Type = 1 // Indicates a received message. Span_TimeEvent_MessageEvent_RECEIVED Span_TimeEvent_MessageEvent_Type = 2 )
func (Span_TimeEvent_MessageEvent_Type) Descriptor ¶
func (Span_TimeEvent_MessageEvent_Type) Descriptor() protoreflect.EnumDescriptor
func (Span_TimeEvent_MessageEvent_Type) Enum ¶
func (x Span_TimeEvent_MessageEvent_Type) Enum() *Span_TimeEvent_MessageEvent_Type
func (Span_TimeEvent_MessageEvent_Type) EnumDescriptor ¶
func (Span_TimeEvent_MessageEvent_Type) EnumDescriptor() ([]byte, []int)
Deprecated: Use Span_TimeEvent_MessageEvent_Type.Descriptor instead.
func (Span_TimeEvent_MessageEvent_Type) Number ¶
func (x Span_TimeEvent_MessageEvent_Type) Number() protoreflect.EnumNumber
func (Span_TimeEvent_MessageEvent_Type) String ¶
func (x Span_TimeEvent_MessageEvent_Type) String() string
func (Span_TimeEvent_MessageEvent_Type) Type ¶
func (Span_TimeEvent_MessageEvent_Type) Type() protoreflect.EnumType
type Span_TimeEvents ¶
type Span_TimeEvents struct {
// A collection of `TimeEvent`s.
TimeEvent []*Span_TimeEvent `protobuf:"bytes,1,rep,name=time_event,json=timeEvent,proto3" json:"time_event,omitempty"`
// The number of dropped annotations in all the included time events.
// If the value is 0, then no annotations were dropped.
DroppedAnnotationsCount int32 `protobuf:"varint,2,opt,name=dropped_annotations_count,json=droppedAnnotationsCount,proto3" json:"dropped_annotations_count,omitempty"`
// The number of dropped message events in all the included time events.
// If the value is 0, then no message events were dropped.
DroppedMessageEventsCount int32 `protobuf:"varint,3,opt,name=dropped_message_events_count,json=droppedMessageEventsCount,proto3" json:"dropped_message_events_count,omitempty"`
// contains filtered or unexported fields
}
A collection of `TimeEvent`s. A `TimeEvent` is a time-stamped annotation on the span, consisting of either user-supplied key:value pairs, or details of a message sent/received between Spans.
func (*Span_TimeEvents) Descriptor ¶
func (*Span_TimeEvents) Descriptor() ([]byte, []int)
Deprecated: Use Span_TimeEvents.ProtoReflect.Descriptor instead.
func (*Span_TimeEvents) GetDroppedAnnotationsCount ¶
func (x *Span_TimeEvents) GetDroppedAnnotationsCount() int32
func (*Span_TimeEvents) GetDroppedMessageEventsCount ¶
func (x *Span_TimeEvents) GetDroppedMessageEventsCount() int32
func (*Span_TimeEvents) GetTimeEvent ¶
func (x *Span_TimeEvents) GetTimeEvent() []*Span_TimeEvent
func (*Span_TimeEvents) ProtoMessage ¶
func (*Span_TimeEvents) ProtoMessage()
func (*Span_TimeEvents) ProtoReflect ¶
func (x *Span_TimeEvents) ProtoReflect() protoreflect.Message
func (*Span_TimeEvents) Reset ¶
func (x *Span_TimeEvents) Reset()
func (*Span_TimeEvents) String ¶
func (x *Span_TimeEvents) String() string
type StackTrace ¶
type StackTrace struct {
// Stack frames in this stack trace. A maximum of 128 frames are allowed.
StackFrames *StackTrace_StackFrames `protobuf:"bytes,1,opt,name=stack_frames,json=stackFrames,proto3" json:"stack_frames,omitempty"`
// The hash ID is used to conserve network bandwidth for duplicate
// stack traces within a single trace.
//
// Often multiple spans will have identical stack traces.
// The first occurrence of a stack trace should contain both the
// `stackFrame` content and a value in `stackTraceHashId`.
//
// Subsequent spans within the same request can refer
// to that stack trace by only setting `stackTraceHashId`.
StackTraceHashId int64 `protobuf:"varint,2,opt,name=stack_trace_hash_id,json=stackTraceHashId,proto3" json:"stack_trace_hash_id,omitempty"`
// contains filtered or unexported fields
}
A call stack appearing in a trace.
func (*StackTrace) Descriptor ¶
func (*StackTrace) Descriptor() ([]byte, []int)
Deprecated: Use StackTrace.ProtoReflect.Descriptor instead.
func (*StackTrace) GetStackFrames ¶
func (x *StackTrace) GetStackFrames() *StackTrace_StackFrames
func (*StackTrace) GetStackTraceHashId ¶
func (x *StackTrace) GetStackTraceHashId() int64
func (*StackTrace) ProtoMessage ¶
func (*StackTrace) ProtoMessage()
func (*StackTrace) ProtoReflect ¶
func (x *StackTrace) ProtoReflect() protoreflect.Message
func (*StackTrace) Reset ¶
func (x *StackTrace) Reset()
func (*StackTrace) String ¶
func (x *StackTrace) String() string
type StackTrace_StackFrame ¶
type StackTrace_StackFrame struct {
// The fully-qualified name that uniquely identifies the function or
// method that is active in this frame (up to 1024 bytes).
FunctionName *TruncatableString `protobuf:"bytes,1,opt,name=function_name,json=functionName,proto3" json:"function_name,omitempty"`
// An un-mangled function name, if `function_name` is mangled.
// To get information about name mangling, run
// [this search](https://www.google.com/search?q=cxx+name+mangling).
// The name can be fully-qualified (up to 1024 bytes).
OriginalFunctionName *TruncatableString `protobuf:"bytes,2,opt,name=original_function_name,json=originalFunctionName,proto3" json:"original_function_name,omitempty"`
// The name of the source file where the function call appears (up to 256
// bytes).
FileName *TruncatableString `protobuf:"bytes,3,opt,name=file_name,json=fileName,proto3" json:"file_name,omitempty"`
// The line number in `file_name` where the function call appears.
LineNumber int64 `protobuf:"varint,4,opt,name=line_number,json=lineNumber,proto3" json:"line_number,omitempty"`
// The column number where the function call appears, if available.
// This is important in JavaScript because of its anonymous functions.
ColumnNumber int64 `protobuf:"varint,5,opt,name=column_number,json=columnNumber,proto3" json:"column_number,omitempty"`
// The binary module from where the code was loaded.
LoadModule *Module `protobuf:"bytes,6,opt,name=load_module,json=loadModule,proto3" json:"load_module,omitempty"`
// The version of the deployed source code (up to 128 bytes).
SourceVersion *TruncatableString `protobuf:"bytes,7,opt,name=source_version,json=sourceVersion,proto3" json:"source_version,omitempty"`
// contains filtered or unexported fields
}
Represents a single stack frame in a stack trace.
func (*StackTrace_StackFrame) Descriptor ¶
func (*StackTrace_StackFrame) Descriptor() ([]byte, []int)
Deprecated: Use StackTrace_StackFrame.ProtoReflect.Descriptor instead.
func (*StackTrace_StackFrame) GetColumnNumber ¶
func (x *StackTrace_StackFrame) GetColumnNumber() int64
func (*StackTrace_StackFrame) GetFileName ¶
func (x *StackTrace_StackFrame) GetFileName() *TruncatableString
func (*StackTrace_StackFrame) GetFunctionName ¶
func (x *StackTrace_StackFrame) GetFunctionName() *TruncatableString
func (*StackTrace_StackFrame) GetLineNumber ¶
func (x *StackTrace_StackFrame) GetLineNumber() int64
func (*StackTrace_StackFrame) GetLoadModule ¶
func (x *StackTrace_StackFrame) GetLoadModule() *Module
func (*StackTrace_StackFrame) GetOriginalFunctionName ¶
func (x *StackTrace_StackFrame) GetOriginalFunctionName() *TruncatableString
func (*StackTrace_StackFrame) GetSourceVersion ¶
func (x *StackTrace_StackFrame) GetSourceVersion() *TruncatableString
func (*StackTrace_StackFrame) ProtoMessage ¶
func (*StackTrace_StackFrame) ProtoMessage()
func (*StackTrace_StackFrame) ProtoReflect ¶
func (x *StackTrace_StackFrame) ProtoReflect() protoreflect.Message
func (*StackTrace_StackFrame) Reset ¶
func (x *StackTrace_StackFrame) Reset()
func (*StackTrace_StackFrame) String ¶
func (x *StackTrace_StackFrame) String() string
type StackTrace_StackFrames ¶
type StackTrace_StackFrames struct {
// Stack frames in this call stack.
Frame []*StackTrace_StackFrame `protobuf:"bytes,1,rep,name=frame,proto3" json:"frame,omitempty"`
// The number of stack frames that were dropped because there
// were too many stack frames.
// If this value is 0, then no stack frames were dropped.
DroppedFramesCount int32 `protobuf:"varint,2,opt,name=dropped_frames_count,json=droppedFramesCount,proto3" json:"dropped_frames_count,omitempty"`
// contains filtered or unexported fields
}
A collection of stack frames, which can be truncated.
func (*StackTrace_StackFrames) Descriptor ¶
func (*StackTrace_StackFrames) Descriptor() ([]byte, []int)
Deprecated: Use StackTrace_StackFrames.ProtoReflect.Descriptor instead.
func (*StackTrace_StackFrames) GetDroppedFramesCount ¶
func (x *StackTrace_StackFrames) GetDroppedFramesCount() int32
func (*StackTrace_StackFrames) GetFrame ¶
func (x *StackTrace_StackFrames) GetFrame() []*StackTrace_StackFrame
func (*StackTrace_StackFrames) ProtoMessage ¶
func (*StackTrace_StackFrames) ProtoMessage()
func (*StackTrace_StackFrames) ProtoReflect ¶
func (x *StackTrace_StackFrames) ProtoReflect() protoreflect.Message
func (*StackTrace_StackFrames) Reset ¶
func (x *StackTrace_StackFrames) Reset()
func (*StackTrace_StackFrames) String ¶
func (x *StackTrace_StackFrames) String() string
type TraceServiceClient ¶
type TraceServiceClient interface {
// Batch writes new spans to new or existing traces. You cannot update
// existing spans.
BatchWriteSpans(ctx context.Context, in *BatchWriteSpansRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Creates a new span.
CreateSpan(ctx context.Context, in *Span, opts ...grpc.CallOption) (*Span, error)
}
TraceServiceClient is the client API for TraceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTraceServiceClient ¶
func NewTraceServiceClient(cc grpc.ClientConnInterface) TraceServiceClient
type TraceServiceServer ¶
type TraceServiceServer interface {
// Batch writes new spans to new or existing traces. You cannot update
// existing spans.
BatchWriteSpans(context.Context, *BatchWriteSpansRequest) (*emptypb.Empty, error)
// Creates a new span.
CreateSpan(context.Context, *Span) (*Span, error)
}
TraceServiceServer is the server API for TraceService service. All implementations should embed UnimplementedTraceServiceServer for forward compatibility
type TruncatableString ¶
type TruncatableString struct {
// The shortened string. For example, if the original string is 500
// bytes long and the limit of the string is 128 bytes, then
// `value` contains the first 128 bytes of the 500-byte string.
//
// Truncation always happens on a UTF8 character boundary. If there
// are multi-byte characters in the string, then the length of the
// shortened string might be less than the size limit.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// The number of bytes removed from the original string. If this
// value is 0, then the string was not shortened.
TruncatedByteCount int32 `protobuf:"varint,2,opt,name=truncated_byte_count,json=truncatedByteCount,proto3" json:"truncated_byte_count,omitempty"`
// contains filtered or unexported fields
}
Represents a string that might be shortened to a specified length.
func (*TruncatableString) Descriptor ¶
func (*TruncatableString) Descriptor() ([]byte, []int)
Deprecated: Use TruncatableString.ProtoReflect.Descriptor instead.
func (*TruncatableString) GetTruncatedByteCount ¶
func (x *TruncatableString) GetTruncatedByteCount() int32
func (*TruncatableString) GetValue ¶
func (x *TruncatableString) GetValue() string
func (*TruncatableString) ProtoMessage ¶
func (*TruncatableString) ProtoMessage()
func (*TruncatableString) ProtoReflect ¶
func (x *TruncatableString) ProtoReflect() protoreflect.Message
func (*TruncatableString) Reset ¶
func (x *TruncatableString) Reset()
func (*TruncatableString) String ¶
func (x *TruncatableString) String() string
type UnimplementedTraceServiceServer ¶
type UnimplementedTraceServiceServer struct {
}
UnimplementedTraceServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedTraceServiceServer) BatchWriteSpans ¶
func (UnimplementedTraceServiceServer) BatchWriteSpans(context.Context, *BatchWriteSpansRequest) (*emptypb.Empty, error)
func (UnimplementedTraceServiceServer) CreateSpan ¶
type UnsafeTraceServiceServer ¶
type UnsafeTraceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTraceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TraceServiceServer will result in compilation errors.
Source Files ¶
trace.pb.go tracing.pb.go tracing_grpc.pb.go
- Version
- v1.11.7 (latest)
- Published
- Oct 9, 2025
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 6 months ago –
Tools for package owners.